@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+from future.builtins import str
 
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured, ValidationError
@@ -7,6 +9,7 @@ from django.utils.text import capfirst
 from django.utils.translation import ugettext_lazy as _
 
 from mezzanine.utils.importing import import_dotted_path
+from future.utils import with_metaclass
 
 
 # Tags and attributes added to richtext filtering whitelist when the
@@ -59,21 +62,19 @@ class RichTextField(models.TextField):
             attrs += LOW_FILTER_ATTRS
         try:
             from bleach import clean
-        except ImportError:
+        except:
             return value
         else:
             return clean(value, tags=tags, attributes=attrs, strip=True,
                          strip_comments=False, styles=styles)
 
 
-class MultiChoiceField(models.CharField):
+class MultiChoiceField(with_metaclass(models.SubfieldBase, models.CharField)):
     """
     Charfield that stores multiple choices selected as a comma
     separated string. Based on http://djangosnippets.org/snippets/2753/
     """
 
-    __metaclass__ = models.SubfieldBase  # triggers to_python()
-
     def formfield(self, *args, **kwargs):
         from mezzanine.core.forms import CheckboxSelectMultiple
         defaults = {
@@ -89,16 +90,16 @@ class MultiChoiceField(models.CharField):
 
     def get_db_prep_value(self, value, **kwargs):
         if isinstance(value, (tuple, list)):
-            value = ",".join([unicode(i) for i in value])
+            value = ",".join([str(i) for i in value])
         return value
 
     def to_python(self, value):
-        if isinstance(value, basestring):
+        if isinstance(value, str):
             value = value.split(",")
         return value
 
     def validate(self, value, instance):
-        choices = [unicode(choice[0]) for choice in self.choices]
+        choices = [str(choice[0]) for choice in self.choices]
         if set(value) - set(choices):
             error = self.error_messages["invalid_choice"] % value
             raise ValidationError(error)
